@@ -6,10 +6,12 @@ try:
     import unittest2 as unittest
 except ImportError:
     import unittest
-    
+
 from neo.core.event import Event
 
 class TestEvent(unittest.TestCase):
-    pass 
+    pass
 
 
+if __name__ == "__main__":
+    unittest.main()
