@@ -6,8 +6,11 @@ try:
     import unittest2 as unittest
 except ImportError:
     import unittest
-    
+
 from neo.core.recordingchannelgroup import RecordingChannelGroup
+import numpy as np
+
+from neo.test.tools import assert_arrays_equal
 
 class TestRecordingChannelGroup(unittest.TestCase):
     def testInitDefaults(self):
@@ -16,18 +19,18 @@ class TestRecordingChannelGroup(unittest.TestCase):
         self.assertEqual(rcg.file_origin, None)
         self.assertEqual(rcg.recordingchannels, [])
         self.assertEqual(rcg.analogsignalarrays, [])
-        self.assertEqual(rcg.channel_names, [])
-        self.assertEqual(rcg.channel_indexes, [])
-    
+        assert_arrays_equal(rcg.channel_names, np.array([]))
+        assert_arrays_equal(rcg.channel_indexes, np.array([]))
+
     def testInit(self):
-        rcg = RecordingChannelGroup(file_origin='temp.dat', channel_indexes=[1])
+        rcg = RecordingChannelGroup(file_origin='temp.dat', channel_indexes=np.array([1]))
         self.assertEqual(rcg.file_origin, 'temp.dat')
         self.assertEqual(rcg.name, None)
         self.assertEqual(rcg.recordingchannels, [])
         self.assertEqual(rcg.analogsignalarrays, [])
-        self.assertEqual(rcg.channel_names, [])
-        self.assertEqual(rcg.channel_indexes, [1])        
+        assert_arrays_equal(rcg.channel_names, np.array([]))
+        assert_arrays_equal(rcg.channel_indexes, np.array([1]))
 
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
